==> ngs-sdk_1.3.0.orig.tar.gz: ngs-1.3.0/ngs-sdk/language/c++/ReadGroupIterator.cpp <==
/*===========================================================================
*
*                            PUBLIC DOMAIN NOTICE
*               National Center for Biotechnology Information
*
*  This software/database is a "United States Government Work" under the
*  terms of the United States Copyright Act.  It was written as part of
*  the author's official duties as a United States Government employee and
*  thus cannot be copyrighted.  This software/database is freely available
*  to the public for use. The National Library of Medicine and the U.S.
*  Government have not placed any restriction on its use or reproduction.
*
*  Although all reasonable efforts have been taken to ensure the accuracy
*  and reliability of the software and data, the NLM and the U.S.
*  Government do not and cannot warrant the performance or results that
*  may be obtained by using this software or data. The NLM and the U.S.
*  Government disclaim all warranties, express or implied, including
*  warranties of performance, merchantability or fitness for any particular
*  purpose.
*
*  Please cite the author in any work or product based on this material.
*
* ===========================================================================
*
*/

#include <ngs/ReadGroupIterator.hpp>

namespace ngs
{

    ReadGroupIterator :: ReadGroupIterator ( ReadGroupRef ref )
            throw ()
        : ReadGroup ( ref )
    {
    }

    ReadGroupIterator & ReadGroupIterator :: operator = ( const ReadGroupIterator & obj )
        throw ( ErrorMsg )
    {
        ReadGroup :: operator = ( obj );
        return * this;
    }

    ReadGroupIterator :: ReadGroupIterator ( const ReadGroupIterator & obj )
            throw ( ErrorMsg )
        : ReadGroup ( obj )
    {
    }
    
    ReadGroupIterator :: ~ ReadGroupIterator ()
        throw ()
    {
    }

} // namespace ngs

==> ngs-sdk_2.11.2.orig.tar.gz: ngs-2.11.2/ngs-sdk/language/c++/ReadGroupIterator.cpp <==
/*===========================================================================
*
*                            PUBLIC DOMAIN NOTICE
*               National Center for Biotechnology Information
*
*  This software/database is a "United States Government Work" under the
*  terms of the United States Copyright Act.  It was written as part of
*  the author's official duties as a United States Government employee and
*  thus cannot be copyrighted.  This software/database is freely available
*  to the public for use. The National Library of Medicine and the U.S.
*  Government have not placed any restriction on its use or reproduction.
*
*  Although all reasonable efforts have been taken to ensure the accuracy
*  and reliability of the software and data, the NLM and the U.S.
*  Government do not and cannot warrant the performance or results that
*  may be obtained by using this software or data. The NLM and the U.S.
*  Government disclaim all warranties, express or implied, including
*  warranties of performance, merchantability or fitness for any particular
*  purpose.
*
*  Please cite the author in any work or product based on this material.
*
* ===========================================================================
*
*/

#include <ngs/ReadGroupIterator.hpp>

namespace ngs
{

    ReadGroupIterator :: ReadGroupIterator ( ReadGroupRef ref )
            NGS_NOTHROW ()
        : ReadGroup ( ref )
    {
    }

    ReadGroupIterator & ReadGroupIterator :: operator = ( const ReadGroupIterator & obj )
        NGS_THROWS ( ErrorMsg )
    {
        ReadGroup :: operator = ( obj );
        return * this;
    }

    ReadGroupIterator :: ReadGroupIterator ( const ReadGroupIterator & obj )
            NGS_THROWS ( ErrorMsg )
        : ReadGroup ( obj )
    {
    }

    ReadGroupIterator :: ~ ReadGroupIterator ()
        NGS_NOTHROW ()
    {
    }

} // namespace ngs
